@@ -100,23 +100,24 @@ def _process_target_sentence(
         cls_token_at_end: Optional[bool] = False,
 ):
     """
-    target_sentence = "첫 회를 시작으로 <13일:DAT>까지 <4일간:DUR> 총 <4회:NOH>에 걸쳐 매 회 <2편:NOH>씩 총 <8편:NOH>이 공개될 예정이다."
-    tokens = ['첫', '회', '##를', '시작으로', '13', '##일까지', '4', '##일간', '총', '4', '##회', '##에', '걸쳐', '매', '회',
-              '2', '##편', '##씩', '총', '8', '##편', '##이', '공개', '##될', '예정이다', '.']
-    label_sequence = ['O', 'O', 'O', 'O', 'B-DAT', 'I-DAT', 'B-DUR', 'I-DUR', 'O', 'B-NOH', 'I-NOH',
-                      'O', 'O', 'O', 'O', 'B-NOH', 'I-NOH', 'O', 'O', 'B-NOH', 'I-NOH', 'O', 'O', 'O', 'O', 'O']
+    target_sentence = "―<효진:PER> 역의 <김환희:PER>(<14:NOH>)가 특히 인상적이었다."
+    tokens = ["―", "효", "##진", "역", "##의", "김", "##환", "##희",
+              "(", "14", ")", "가", "특히", "인상", "##적이", "##었다", "."]
+    label_sequence = ['O', 'B-PER', 'I-PER', 'O', 'O', 'B-PER', 'I-PER', 'I-PER', 'O',
+                      'B-NOH', 'O', 'O', 'O', 'O', 'O', 'O', 'O']
     """
-    prefix_sum_of_token_start_index, sum = [], 0
+    prefix_sum_of_token_start_index, sum = [0], 0
     for i, token in enumerate(tokens):
-        if i == 0:
-            prefix_sum_of_token_start_index.append(0)
-            sum += len(token) - 1
+        if token.startswith("##"):
+            sum += len(token) - 2
+        elif token in ["[UNK]"]:
+            sum += 1 # 대부분 ', "
         else:
-            prefix_sum_of_token_start_index.append(sum)
             sum += len(token)
+        prefix_sum_of_token_start_index.append(sum)
 
     regex_ner = re.compile('<(.+?):[A-Z]{3}>')  # NER Tag가 2자리 문자면 {3} -> {2}로 변경 (e.g. LOC -> LC) 인경우
-    regex_filter_res = regex_ner.finditer(target_sentence)
+    regex_filter_res = regex_ner.finditer(target_sentence.replace(" ", ""))
 
     list_of_ner_tag = []
     list_of_ner_text = []
@@ -141,9 +142,6 @@ def _process_target_sentence(
     for tup in zip(tokens, prefix_sum_of_token_start_index):
         token, index = tup
 
-        if '▁' in token:  # 주의할 점!! '▁' 이것과 우리가 쓰는 underscore '_'는 서로 다른 토큰임
-            index += 1  # 토큰이 띄어쓰기를 앞단에 포함한 경우 index 한개 앞으로 당김 # ('▁13', 9) -> ('13', 10)
-
         if entity_index < len(list_of_tuple_ner_start_end):
             start, end = list_of_tuple_ner_start_end[entity_index]
 
